<?php

namespace Litecms\LandlordServices\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\LandlordServices\Http\Requests\LandlordServicesRequest;
use Litecms\LandlordServices\Interfaces\LandlordServicesRepositoryInterface;
use Litecms\LandlordServices\Models\LandlordServices;

/**
 * Resource controller class for landlord_services.
 */
class LandlordServicesResourceController extends BaseController
{

    /**
     * Initialize landlord_services resource controller.
     *
     * @param type LandlordServicesRepositoryInterface $landlord_services
     *
     * @return null
     */
    public function __construct(LandlordServicesRepositoryInterface $landlord_services)
    {
        parent::__construct();
        $this->repository = $landlord_services;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\LandlordServices\Repositories\Criteria\LandlordServicesResourceCriteria::class);
    }

    /**
     * Display a list of landlord_services.
     *
     * @return Response
     */
    public function index(LandlordServicesRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\LandlordServices\Repositories\Presenter\LandlordServicesPresenter::class)
                ->$function();
        }

        $landlord_services = $this->repository->paginate();

        return $this->response->title(trans('landlord_services::landlord_services.names'))
            ->view('landlord_services::landlord_services.index', true)
            ->data(compact('landlord_services'))
            ->output();
    }

    /**
     * Display landlord_services.
     *
     * @param Request $request
     * @param Model   $landlord_services
     *
     * @return Response
     */
    public function show(LandlordServicesRequest $request, LandlordServices $landlord_services)
    {

        if ($landlord_services->exists) {
            $view = 'landlord_services::landlord_services.show';
        } else {
            $view = 'landlord_services::landlord_services.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('landlord_services::landlord_services.name'))
            ->data(compact('landlord_services'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new landlord_services.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(LandlordServicesRequest $request)
    {

        $landlord_services = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('landlord_services::landlord_services.name')) 
            ->view('landlord_services::landlord_services.create', true) 
            ->data(compact('landlord_services'))
            ->output();
    }

    /**
     * Create new landlord_services.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(LandlordServicesRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $landlord_services                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('landlord_services::landlord_services.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('landlord_services/landlord_services/' . $landlord_services->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/landlord_services/landlord_services'))
                ->redirect();
        }

    }

    /**
     * Show landlord_services for editing.
     *
     * @param Request $request
     * @param Model   $landlord_services
     *
     * @return Response
     */
    public function edit(LandlordServicesRequest $request, LandlordServices $landlord_services)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('landlord_services::landlord_services.name'))
            ->view('landlord_services::landlord_services.edit', true)
            ->data(compact('landlord_services'))
            ->output();
    }

    /**
     * Update the landlord_services.
     *
     * @param Request $request
     * @param Model   $landlord_services
     *
     * @return Response
     */
    public function update(LandlordServicesRequest $request, LandlordServices $landlord_services)
    {
        try {
            $attributes = $request->all();

            $landlord_services->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('landlord_services::landlord_services.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('landlord_services/landlord_services/' . $landlord_services->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('landlord_services/landlord_services/' . $landlord_services->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the landlord_services.
     *
     * @param Model   $landlord_services
     *
     * @return Response
     */
    public function destroy(LandlordServicesRequest $request, LandlordServices $landlord_services)
    {
        try {

            $landlord_services->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('landlord_services::landlord_services.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('landlord_services/landlord_services/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('landlord_services/landlord_services/' . $landlord_services->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple landlord_services.
     *
     * @param Model   $landlord_services
     *
     * @return Response
     */
    public function delete(LandlordServicesRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('landlord_services::landlord_services.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('landlord_services/landlord_services'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/landlord_services/landlord_services'))
                ->redirect();
        }

    }

    /**
     * Restore deleted landlord_services.
     *
     * @param Model   $landlord_services
     *
     * @return Response
     */
    public function restore(LandlordServicesRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('landlord_services::landlord_services.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/landlord_services/landlord_services'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/landlord_services/landlord_services/'))
                ->redirect();
        }

    }

}
