<?php

namespace Litecms\LandlordServices\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\LandlordServices\Models\LandlordServices;

class LandlordServicesPolicy
{

    /**
     * Determine if the given user can view the landlord_services.
     *
     * @param UserPolicy $user
     * @param LandlordServices $landlord_services
     *
     * @return bool
     */
    public function view(UserPolicy $user, LandlordServices $landlord_services)
    {
        if ($user->canDo('landlord_services.landlord_services.view') && $user->isAdmin()) {
            return true;
        }

        return $landlord_services->user_id == user_id() && $landlord_services->user_type == user_type();
    }

    /**
     * Determine if the given user can create a landlord_services.
     *
     * @param UserPolicy $user
     * @param LandlordServices $landlord_services
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('landlord_services.landlord_services.create');
    }

    /**
     * Determine if the given user can update the given landlord_services.
     *
     * @param UserPolicy $user
     * @param LandlordServices $landlord_services
     *
     * @return bool
     */
    public function update(UserPolicy $user, LandlordServices $landlord_services)
    {
        if ($user->canDo('landlord_services.landlord_services.edit') && $user->isAdmin()) {
            return true;
        }

        return $landlord_services->user_id == user_id() && $landlord_services->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given landlord_services.
     *
     * @param UserPolicy $user
     * @param LandlordServices $landlord_services
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, LandlordServices $landlord_services)
    {
        return $landlord_services->user_id == user_id() && $landlord_services->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given landlord_services.
     *
     * @param UserPolicy $user
     * @param LandlordServices $landlord_services
     *
     * @return bool
     */
    public function verify(UserPolicy $user, LandlordServices $landlord_services)
    {
        if ($user->canDo('landlord_services.landlord_services.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given landlord_services.
     *
     * @param UserPolicy $user
     * @param LandlordServices $landlord_services
     *
     * @return bool
     */
    public function approve(UserPolicy $user, LandlordServices $landlord_services)
    {
        if ($user->canDo('landlord_services.landlord_services.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
