<?php

namespace Litecms\LandlordServices\Providers;

use Illuminate\Support\ServiceProvider;

class LandlordServicesServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'landlord_services');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'landlord_services');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.landlord_services', function ($app) {
            return $this->app->make('Litecms\LandlordServices\LandlordServices');
        });

                // Bind LandlordServices to repository
        $this->app->bind(
            'Litecms\LandlordServices\Interfaces\LandlordServicesRepositoryInterface',
            \Litecms\LandlordServices\Repositories\Eloquent\LandlordServicesRepository::class
        );

        $this->app->register(\Litecms\LandlordServices\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\LandlordServices\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\LandlordServices\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.landlord_services'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/landlord_services.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/landlord_services')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/landlord_services')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
